summaryrefslogtreecommitdiff
path: root/build-aux/qmi-codegen/utils.py
diff options
context:
space:
mode:
Diffstat (limited to 'build-aux/qmi-codegen/utils.py')
-rw-r--r--build-aux/qmi-codegen/utils.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/build-aux/qmi-codegen/utils.py b/build-aux/qmi-codegen/utils.py
index dcf8a0db..a65e6307 100644
--- a/build-aux/qmi-codegen/utils.py
+++ b/build-aux/qmi-codegen/utils.py
@@ -77,8 +77,8 @@ def add_header_start(f, output_name, service):
else:
template += (
"#include \"qmi-enums-private.h\"\n")
- # DMS, NAS and LOC have flags64
- if service in ('DMS', 'NAS', 'LOC'):
+ # DMS, NAS, LOC and DSD have flags64
+ if service in ('DMS', 'NAS', 'LOC', 'DSD'):
template += (
"#include \"qmi-flags64-${service}.h\"\n")
template += (